pub fn validate_repository_with<'a>(
root: impl AsRef<Path>,
validators: impl IntoIterator<Item = &'a dyn AdditionalValidator>,
) -> Vec<Diagnostic>Expand description
Validates a repository with the built-in rules followed by every supplied domain validator.
All validators run even when another validator reports diagnostics. The returned diagnostics are sorted deterministically by path, line, identifier, message, and validation layer.